@@ -70,8 +70,8 @@ void AudioOptsDialog::buildTestControls(PlotScalar **plotScalar, wxButton **btnT
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
 AudioOptsDialog::AudioOptsDialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style) : wxDialog(parent, id, title, pos, size, style)
 {
-    this->SetSizeHints(wxSize(850, 600), wxDefaultSize);
-
+    //this->SetSizeHints(wxSize(850, 600), wxDefaultSize);
+    fprintf(stderr, "pos %d %d\n", pos.x, pos.y);
     Pa_Init();
 
     wxBoxSizer* mainSizer;
