@@ -30,7 +30,6 @@
 
 #include <wx/tglbtn.h>
 #include <wx/app.h>
-//#include <wx/aboutdlg.h>
 #include "wx/rawbmp.h"
 #include "wx/file.h"
 #include "wx/filename.h"
@@ -53,7 +52,6 @@
 
 #include <samplerate.h>
 
-#include <hamlib.h> 
 #include <stdint.h>
 #include <speex/speex_preprocess.h>
 
@@ -62,6 +60,7 @@
 #else
 #include <termios.h>
 #include <sys/ioctl.h>
+#include <dlfcn.h>
 #endif
 
 #include "codec2.h"
@@ -85,6 +84,9 @@
 #include "varicode.h"
 #include "sox_biquad.h"
 #include "comp_prim.h"
+#include "dlg_plugin.h"
+#include "hamlib.h"
+#include "serialport.h" 
 
 #define _USE_TIMER              1
 #define _USE_ONIDLE             1
@@ -104,13 +106,6 @@ enum {
 #define EXCHANGE_DATA_IN    0
 #define EXCHANGE_DATA_OUT   1
 
-#ifdef _WIN32
-#define COM_HANDLE_INVALID			INVALID_HANDLE_VALUE
-typedef HANDLE      com_handle_t;
-#else
-#define COM_HANDLE_INVALID			-1
-typedef int         com_handle_t;
-#endif
 
 extern int                 g_nSoundCards;
 extern int                 g_soundCard1InDeviceNum;
@@ -182,6 +177,7 @@ class MainApp : public wxApp
         bool                m_boolHamlibUseForPTT;
         unsigned int        m_intHamlibRig;
         wxString            m_strHamlibSerialPort;
+        unsigned int        m_intHamlibSerialRate;
         Hamlib              *m_hamlib;
 
         bool                m_boolUseSerialPTT;
@@ -190,6 +186,7 @@ class MainApp : public wxApp
         bool                m_boolRTSPos;
         bool                m_boolUseDTR;
         bool                m_boolDTRPos;
+        Serialport         *m_serialport;
 
         // Play/Rec files
 
@@ -268,6 +265,22 @@ class MainApp : public wxApp
         bool                loadConfig();
         bool                saveConfig();
 
+        // Plugins -----------------------------------
+
+        wxString            m_txtPlugInParam[PLUGIN_MAX_PARAMS];
+
+        // plugin details
+
+        void      *m_plugInHandle;
+        bool       m_plugIn;
+        wxString   m_plugInName;
+        int        m_numPlugInParam;
+        wxString   m_plugInParamName[PLUGIN_MAX_PARAMS];
+        void      *m_plugInStates;
+        void     (*m_plugin_startfp)(void *);
+        void     (*m_plugin_stopfp)(void *);
+        void     (*m_plugin_rx_samplesfp)(void *, short *, int);
+
         // misc
 
         bool       m_testFrames;
@@ -277,7 +290,29 @@ class MainApp : public wxApp
         int        FilterEvent(wxEvent& event);
         MainFrame *frame;
 
+        // 700 options
+
         bool       m_FreeDV700txClip;
+        bool       m_FreeDV700Combine;
+
+        // Noise simulation
+
+        int        m_noise_snr;
+
+        // carrier attenuation
+
+        bool       m_attn_carrier_en;
+        int        m_attn_carrier;
+
+        // tone interferer simulation
+
+        bool       m_tone;
+        int        m_tone_freq_hz;
+        int        m_tone_amplitude;
+
+        // Windows debug console
+
+        bool       m_debug_console;
     protected:
 };
 
@@ -379,7 +414,7 @@ class UDPThread;
 class MainFrame : public TopFrame
 {
     public:
-        MainFrame(wxWindow *parent);
+        MainFrame(wxString plugInName, wxWindow *parent);
         virtual ~MainFrame();
 
         PlotSpectrum*           m_panelSpectrum;
@@ -406,7 +441,7 @@ class MainFrame : public TopFrame
         txRxThread*             m_txRxThread;
 
         bool                    OpenHamlibRig();
-        void                    SetupSerialPort(void);
+        void                    OpenSerialPort(void);
         void                    CloseSerialPort(void);
         void                    SerialPTTRx(void);
 
@@ -457,20 +492,6 @@ class MainFrame : public TopFrame
 
     protected:
 
-#ifdef _WIN32
-#define COM_HANDLE_INVALID			INVALID_HANDLE_VALUE
-        com_handle_t  com_handle;
-#else
-#define COM_HANDLE_INVALID			-1
-        com_handle_t  com_handle;
-#endif
-        void raiseDTR(void);
-        void lowerDTR(void);
-        void raiseRTS(void);
-        void lowerRTS(void);
-        bool openComPort(const char *port);
-        void closeComPort(void);
-
         void setsnrBeta(bool snrSlow);
 
         // protected event handlers
@@ -495,6 +516,9 @@ class MainFrame : public TopFrame
         void OnToolsOptions(wxCommandEvent& event);
         void OnToolsOptionsUI(wxUpdateUIEvent& event);
 
+        void OnToolsPlugInCfg( wxCommandEvent& event );
+        void OnToolsPlugInCfgUI( wxUpdateUIEvent& event );
+
         void OnPlayFileToMicIn( wxCommandEvent& event );
         void StopPlayFileToMicIn(void);
         void OnRecFileFromRadio( wxCommandEvent& event );
@@ -650,4 +674,8 @@ void my_put_next_rx_char(void *callback_state, char c);
 
 void freq_shift_coh(COMP rx_fdm_fcorr[], COMP rx_fdm[], float foff, float Fs, COMP *foff_phase_rect, int nin);
 
+// Helper function called by plugin
+
+int plugin_get_persistant(char name[], char value[]);
+
 #endif //__FDMDV2_MAIN__
